==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/reef/dialogs_de.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("Meine Güte, durch den Aufschlag ist die Höhle eingestürzt!")


dialogId("uts-v-projet0", "font_big", "I can`t go through this cave-in, we have to find another exit.")
dialogStr("Ich komme da nicht durch, wir müssen einen anderen Ausgang finden.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Das geht nicht.")


dialogId("uts-v-sam", "font_big", "I won`t make it alone.")
dialogStr("Ich schaffe das nicht alleine.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Ich hätte wahrscheinlich diese Muschel zuerst anheben sollen.")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Vielleicht müssen wir diese Gegenstände vertauschen.")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Eine Matratze. Das beste Ding, das man unter Wasser haben kann.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Jetzt können wir die Schnecke auf die Matratze fallen lassen.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Es wird schwierig, die Schnecke von dort aufzuheben.")


dialogId("uts-v-konecne", "font_big", "Finally, it`s there.")
dialogStr("Endlich ist sie da.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Die arme Schnecke...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Wir sollten die Korallenriffe absuchen.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Dort werden viele interessante Wesen zu untersuchen sein.")


dialogId("uts-v-mikroskop", "font_big", "Don`t we need a microscope to investigate corals?")
dialogStr("Brauchen wir nicht ein Mikroskop, um Korallen zu untersuchen?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Ja, die sind klein. Aber dort können auch andere Lebensformen sein.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Zum Beispiel Korallenschildkröten.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Und außerdem habe ich den Verdacht, dass dieses Mikroskop in einem Tauchboot ist.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/reef/dialogs_de.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("Meine Güte, durch den Aufschlag ist die Höhle eingestürzt!")


dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("Ich komme da nicht durch, wir müssen einen anderen Ausgang finden.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Das geht nicht.")


dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("Ich schaffe das nicht alleine.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Ich hätte wahrscheinlich diese Muschel zuerst anheben sollen.")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Vielleicht müssen wir diese Gegenstände vertauschen.")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Eine Matratze. Das beste Ding, das man unter Wasser haben kann.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Jetzt können wir die Schnecke auf die Matratze fallen lassen.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Es wird schwierig, die Schnecke von dort aufzuheben.")


dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("Endlich ist sie da.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Die arme Schnecke...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Wir sollten die Korallenriffe absuchen.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Dort werden viele interessante Wesen zu untersuchen sein.")


dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("Brauchen wir nicht ein Mikroskop, um Korallen zu untersuchen?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("Ja, die sind klein. Aber dort können auch andere Lebensformen sein.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Zum Beispiel Korallenschildkröten.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Und außerdem habe ich den Verdacht, dass dieses Mikroskop in einem Tauchboot ist.")
